wallaroo.wallaroo_ml_ops_api_client.models.assays_get_results_json_body API documentation

# wallaroo.wallaroo_ml_ops_api_client.models.assays_get_results_json_body

View Source

     1from typing import Any, Dict, List, Type, TypeVar, Union
     2
     3import attr
     4
     5from ..types import UNSET, Unset
     6
     7T = TypeVar("T", bound="AssaysGetResultsJsonBody")
     8
     9@attr.s(auto_attribs=True)
    10class AssaysGetResultsJsonBody:
    11    """ Request to return assay results.
    12
    13    Attributes:
    14        assay_id (Union[Unset, None, int]):  Assay identifier.
    15        start (Union[Unset, None, str]):  Start date and time.
    16        end (Union[Unset, None, str]):  End date and time.
    17        limit (Union[Unset, None, int]):  Maximum number of results to return.
    18        pipeline_id (Union[Unset, None, int]):  Pipeline identifier.
    19    """
    20
    21    assay_id: Union[Unset, None, int] = UNSET
    22    start: Union[Unset, None, str] = UNSET
    23    end: Union[Unset, None, str] = UNSET
    24    limit: Union[Unset, None, int] = UNSET
    25    pipeline_id: Union[Unset, None, int] = UNSET
    26    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
    27
    28
    29    def to_dict(self) -> Dict[str, Any]:
    30        assay_id = self.assay_id
    31        start = self.start
    32        end = self.end
    33        limit = self.limit
    34        pipeline_id = self.pipeline_id
    35
    36        field_dict: Dict[str, Any] = {}
    37        field_dict.update(self.additional_properties)
    38        field_dict.update({
    39        })
    40        if assay_id is not UNSET:
    41            field_dict["assay_id"] = assay_id
    42        if start is not UNSET:
    43            field_dict["start"] = start
    44        if end is not UNSET:
    45            field_dict["end"] = end
    46        if limit is not UNSET:
    47            field_dict["limit"] = limit
    48        if pipeline_id is not UNSET:
    49            field_dict["pipeline_id"] = pipeline_id
    50
    51        return field_dict
    52
    53
    54
    55    @classmethod
    56    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
    57        d = src_dict.copy()
    58        assay_id = d.pop("assay_id", UNSET)
    59
    60        start = d.pop("start", UNSET)
    61
    62        end = d.pop("end", UNSET)
    63
    64        limit = d.pop("limit", UNSET)
    65
    66        pipeline_id = d.pop("pipeline_id", UNSET)
    67
    68        assays_get_results_json_body = cls(
    69            assay_id=assay_id,
    70            start=start,
    71            end=end,
    72            limit=limit,
    73            pipeline_id=pipeline_id,
    74        )
    75
    76        assays_get_results_json_body.additional_properties = d
    77        return assays_get_results_json_body
    78
    79    @property
    80    def additional_keys(self) -> List[str]:
    81        return list(self.additional_properties.keys())
    82
    83    def __getitem__(self, key: str) -> Any:
    84        return self.additional_properties[key]
    85
    86    def __setitem__(self, key: str, value: Any) -> None:
    87        self.additional_properties[key] = value
    88
    89    def __delitem__(self, key: str) -> None:
    90        del self.additional_properties[key]
    91
    92    def __contains__(self, key: str) -> bool:
    93        return key in self.additional_properties

@attr.s(auto_attribs=True)
class AssaysGetResultsJsonBody: View Source

    10@attr.s(auto_attribs=True)
    11class AssaysGetResultsJsonBody:
    12    """ Request to return assay results.
    13
    14    Attributes:
    15        assay_id (Union[Unset, None, int]):  Assay identifier.
    16        start (Union[Unset, None, str]):  Start date and time.
    17        end (Union[Unset, None, str]):  End date and time.
    18        limit (Union[Unset, None, int]):  Maximum number of results to return.
    19        pipeline_id (Union[Unset, None, int]):  Pipeline identifier.
    20    """
    21
    22    assay_id: Union[Unset, None, int] = UNSET
    23    start: Union[Unset, None, str] = UNSET
    24    end: Union[Unset, None, str] = UNSET
    25    limit: Union[Unset, None, int] = UNSET
    26    pipeline_id: Union[Unset, None, int] = UNSET
    27    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
    28
    29
    30    def to_dict(self) -> Dict[str, Any]:
    31        assay_id = self.assay_id
    32        start = self.start
    33        end = self.end
    34        limit = self.limit
    35        pipeline_id = self.pipeline_id
    36
    37        field_dict: Dict[str, Any] = {}
    38        field_dict.update(self.additional_properties)
    39        field_dict.update({
    40        })
    41        if assay_id is not UNSET:
    42            field_dict["assay_id"] = assay_id
    43        if start is not UNSET:
    44            field_dict["start"] = start
    45        if end is not UNSET:
    46            field_dict["end"] = end
    47        if limit is not UNSET:
    48            field_dict["limit"] = limit
    49        if pipeline_id is not UNSET:
    50            field_dict["pipeline_id"] = pipeline_id
    51
    52        return field_dict
    53
    54
    55
    56    @classmethod
    57    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
    58        d = src_dict.copy()
    59        assay_id = d.pop("assay_id", UNSET)
    60
    61        start = d.pop("start", UNSET)
    62
    63        end = d.pop("end", UNSET)
    64
    65        limit = d.pop("limit", UNSET)
    66
    67        pipeline_id = d.pop("pipeline_id", UNSET)
    68
    69        assays_get_results_json_body = cls(
    70            assay_id=assay_id,
    71            start=start,
    72            end=end,
    73            limit=limit,
    74            pipeline_id=pipeline_id,
    75        )
    76
    77        assays_get_results_json_body.additional_properties = d
    78        return assays_get_results_json_body
    79
    80    @property
    81    def additional_keys(self) -> List[str]:
    82        return list(self.additional_properties.keys())
    83
    84    def __getitem__(self, key: str) -> Any:
    85        return self.additional_properties[key]
    86
    87    def __setitem__(self, key: str, value: Any) -> None:
    88        self.additional_properties[key] = value
    89
    90    def __delitem__(self, key: str) -> None:
    91        del self.additional_properties[key]
    92
    93    def __contains__(self, key: str) -> bool:
    94        return key in self.additional_properties

Request to return assay results.

Attributes: assay_id (Union[Unset, None, int]): Assay identifier. start (Union[Unset, None, str]): Start date and time. end (Union[Unset, None, str]): End date and time. limit (Union[Unset, None, int]): Maximum number of results to return. pipeline_id (Union[Unset, None, int]): Pipeline identifier.

AssaysGetResultsJsonBody( assay_id: Union[wallaroo.wallaroo_ml_ops_api_client.types.Unset, NoneType, int] = <wallaroo.wallaroo_ml_ops_api_client.types.Unset object>, start: Union[wallaroo.wallaroo_ml_ops_api_client.types.Unset, NoneType, str] = <wallaroo.wallaroo_ml_ops_api_client.types.Unset object>, end: Union[wallaroo.wallaroo_ml_ops_api_client.types.Unset, NoneType, str] = <wallaroo.wallaroo_ml_ops_api_client.types.Unset object>, limit: Union[wallaroo.wallaroo_ml_ops_api_client.types.Unset, NoneType, int] = <wallaroo.wallaroo_ml_ops_api_client.types.Unset object>, pipeline_id: Union[wallaroo.wallaroo_ml_ops_api_client.types.Unset, NoneType, int] = <wallaroo.wallaroo_ml_ops_api_client.types.Unset object>) View Source

    2def __init__(self, assay_id=attr_dict['assay_id'].default, start=attr_dict['start'].default, end=attr_dict['end'].default, limit=attr_dict['limit'].default, pipeline_id=attr_dict['pipeline_id'].default):
    3    self.assay_id = assay_id
    4    self.start = start
    5    self.end = end
    6    self.limit = limit
    7    self.pipeline_id = pipeline_id
    8    self.additional_properties = __attr_factory_additional_properties()

Method generated by attrs for class AssaysGetResultsJsonBody.

def to_dict(self) -> Dict[str, Any]: View Source

    30    def to_dict(self) -> Dict[str, Any]:
    31        assay_id = self.assay_id
    32        start = self.start
    33        end = self.end
    34        limit = self.limit
    35        pipeline_id = self.pipeline_id
    36
    37        field_dict: Dict[str, Any] = {}
    38        field_dict.update(self.additional_properties)
    39        field_dict.update({
    40        })
    41        if assay_id is not UNSET:
    42            field_dict["assay_id"] = assay_id
    43        if start is not UNSET:
    44            field_dict["start"] = start
    45        if end is not UNSET:
    46            field_dict["end"] = end
    47        if limit is not UNSET:
    48            field_dict["limit"] = limit
    49        if pipeline_id is not UNSET:
    50            field_dict["pipeline_id"] = pipeline_id
    51
    52        return field_dict

@classmethod
def from_dict(cls: Type[~T], src_dict: Dict[str, Any]) -> ~T: View Source

    56    @classmethod
    57    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
    58        d = src_dict.copy()
    59        assay_id = d.pop("assay_id", UNSET)
    60
    61        start = d.pop("start", UNSET)
    62
    63        end = d.pop("end", UNSET)
    64
    65        limit = d.pop("limit", UNSET)
    66
    67        pipeline_id = d.pop("pipeline_id", UNSET)
    68
    69        assays_get_results_json_body = cls(
    70            assay_id=assay_id,
    71            start=start,
    72            end=end,
    73            limit=limit,
    74            pipeline_id=pipeline_id,
    75        )
    76
    77        assays_get_results_json_body.additional_properties = d
    78        return assays_get_results_json_body

additional_keys: List[str]